@@ -6,7 +6,7 @@ use XML::Parser::Expat;
 
 # TODO: convert to Class::Std::Fast based class - hash based classes suck.
 
-our $VERSION = '2.00_27';
+our $VERSION = '2.00_32';
 
 sub new {
     my ($class, $arg_ref) = @_;
@@ -15,20 +15,45 @@ sub new {
 
     $self->set_user_agent($arg_ref->{ user_agent })
         if $arg_ref->{ user_agent };
+    $self->{ parsed } = $arg_ref->{ parsed } if $arg_ref->{ parsed };
 
     return $self;
 }
 
+sub clone {
+    my $self = shift;
+    my $class = ref $self;
+    my $clone = $class->new($self);
+    return $clone;
+}
+
 sub set_uri { $_[0]->{ uri } = $_[1]; }
 sub get_uri { return $_[0]->{ uri }; }
 
 sub set_user_agent { $_[0]->{ user_agent } = $_[1]; }
 sub get_user_agent { return $_[0]->{ user_agent }; }
 
+sub set_parsed {
+    my ($self, $uri) = @_;
+    $self->{ parsed }->{ $uri } = 1;
+    return;
+}
+
+sub is_parsed {
+    my ($self, $uri) = @_;
+    return exists $self->{ parsed }->{ $uri };
+}
 
 sub parse_uri {
     my $self = shift;
     my $uri = shift;
+
+    if ($self->is_parsed($uri)){
+        warn "$uri already imported. Ignoring it\n";
+        return;
+    }
+    $self->set_parsed($uri);
+
     $self->set_uri( $uri );
 
     if (not $self->{ user_agent }) {
@@ -37,7 +62,6 @@ sub parse_uri {
     }
 
     my $response = $self->{ user_agent }->get($uri);
-
     die $response->message() if $response->code() ne '200';
     return $self->parse( $response->content() );
 }
